// import java.lang.*;
// No need: java.lang is implicitly imported

public class Example1 {
	public static void main(String[] args){
		Point p1= new Point(3,2);
		Point p2= new Point(-1,-1);
		Rectangle r= new Rectangle(p1, p2);
		System.out.print("Point 1: ");
		System.out.println(p1.toString());
		System.out.print("Point 2: ");
		System.out.println(p2.toString());
		System.out.print("Rectangle: ");
		System.out.println(r.toString());
		System.out.print("Area: ");
		System.out.println(r.calculateArea());
		System.out.print("Perimeter: ");
		System.out.println(r.calculatePerimeter());
	}
}

